QuickWeb
========
`Jinja2` is a Rapid Development Python Web Framework powered by `CherryPy` and `Mako`

If you just need a simple site with static but structured layout that can be deployed to your own server, or to
an web application engine hosting, QuickWeb maybe your best option.

.. include:: install.md
.. include:: webappdevelopment.md


